OiRA

# Zertifikat

This certificate is presented to

Hans Mittelmaier

For successfully finishing the training for Gefährdungsbeurteilung Logistik on 7 September 2019.

Tool | Department
--- | ---
Mercedes-Benz Special Trucks - Montagelinien & Vormontagen | FC, Bodo K

Print certificate
Back

## certificate-view.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More